/*
 * Copyright (C) Sureshot 2002
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Review history:
 *
 */

package se.bysoft.sureshot.util.config;

/**
 * Interface for mappings key -> string.
 *
 * @author Roger Karlsson
 * @since  April 10, 2002
 */
public interface ValueStorage 
{
    /**
     * Get the value associated with the key.
     * 
     * @param key           The key.
     * @param defaultValue  This string is returned if no mapping exists.
     *
     * @return The value associated with the key. If no mapping is
     *         available the default value is returned.
     */
    String get(String key, String defaultValue);
    
    /**
     * Maps a key to a value.
     *
     * @param key    The key.
     * @param value  The value associated with the key.
     *
     * @exception ValueStorageException   Thrown if some problem occured when
     *                                    storing the mapping (on disk for 
     *                                    example).
     */
    void set(String key, String value) throws ValueStorageException;
}

